"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2IdentitiesDeleteIdentityRequestBodyTypedDict(TypedDict):
    identity: str
    r"""The ID of the identity to delete. This can be either the externalId (from your own system that was used during identity creation) or the identityId (the internal ID returned by the identity service)."""


class V2IdentitiesDeleteIdentityRequestBody(BaseModel):
    identity: str
    r"""The ID of the identity to delete. This can be either the externalId (from your own system that was used during identity creation) or the identityId (the internal ID returned by the identity service)."""
