"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .meta import Meta, MetaTypedDict
from .v2ratelimitdeleteoverrideresponsedata import (
    V2RatelimitDeleteOverrideResponseData,
    V2RatelimitDeleteOverrideResponseDataTypedDict,
)
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2RatelimitDeleteOverrideResponseBodyTypedDict(TypedDict):
    meta: MetaTypedDict
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""
    data: V2RatelimitDeleteOverrideResponseDataTypedDict
    r"""Empty response object. A successful response indicates the override was successfully deleted. The operation is immediate - as soon as this response is received, the override no longer exists and affected identifiers have reverted to using the default rate limit for the namespace. No other data is returned as part of the deletion operation."""


class V2RatelimitDeleteOverrideResponseBody(BaseModel):
    meta: Meta
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""

    data: V2RatelimitDeleteOverrideResponseData
    r"""Empty response object. A successful response indicates the override was successfully deleted. The operation is immediate - as soon as this response is received, the override no longer exists and affected identifiers have reverted to using the default rate limit for the namespace. No other data is returned as part of the deletion operation."""
