"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .badrequesterrordetails import (
        BadRequestErrorDetails,
        BadRequestErrorDetailsTypedDict,
    )
    from .baseerror import BaseError, BaseErrorTypedDict
    from .emptyresponse import EmptyResponse, EmptyResponseTypedDict
    from .identities_listidentitiesop import (
        IdentitiesListIdentitiesResponse,
        IdentitiesListIdentitiesResponseTypedDict,
    )
    from .identity import (
        Identity,
        IdentityMeta,
        IdentityMetaTypedDict,
        IdentityTypedDict,
    )
    from .keycreditsdata import KeyCreditsData, KeyCreditsDataTypedDict
    from .keycreditsrefill import Interval, KeyCreditsRefill, KeyCreditsRefillTypedDict
    from .keyresponsedata import KeyResponseData, KeyResponseDataTypedDict
    from .keysverifykeycredits import (
        KeysVerifyKeyCredits,
        KeysVerifyKeyCreditsTypedDict,
    )
    from .keysverifykeyratelimit import (
        KeysVerifyKeyRatelimit,
        KeysVerifyKeyRatelimitTypedDict,
    )
    from .meta import Meta, MetaTypedDict
    from .pagination import Pagination, PaginationTypedDict
    from .permission import Permission, PermissionTypedDict
    from .ratelimitoverride import RatelimitOverride, RatelimitOverrideTypedDict
    from .ratelimitrequest import RatelimitRequest, RatelimitRequestTypedDict
    from .ratelimitresponse import RatelimitResponse, RatelimitResponseTypedDict
    from .role import Role, RoleTypedDict
    from .security import Security, SecurityTypedDict
    from .v2apiscreateapirequestbody import (
        V2ApisCreateAPIRequestBody,
        V2ApisCreateAPIRequestBodyTypedDict,
    )
    from .v2apiscreateapiresponsebody import (
        V2ApisCreateAPIResponseBody,
        V2ApisCreateAPIResponseBodyTypedDict,
    )
    from .v2apiscreateapiresponsedata import (
        V2ApisCreateAPIResponseData,
        V2ApisCreateAPIResponseDataTypedDict,
    )
    from .v2apisdeleteapirequestbody import (
        V2ApisDeleteAPIRequestBody,
        V2ApisDeleteAPIRequestBodyTypedDict,
    )
    from .v2apisdeleteapiresponsebody import (
        V2ApisDeleteAPIResponseBody,
        V2ApisDeleteAPIResponseBodyTypedDict,
    )
    from .v2apisgetapirequestbody import (
        V2ApisGetAPIRequestBody,
        V2ApisGetAPIRequestBodyTypedDict,
    )
    from .v2apisgetapiresponsebody import (
        V2ApisGetAPIResponseBody,
        V2ApisGetAPIResponseBodyTypedDict,
    )
    from .v2apisgetapiresponsedata import (
        V2ApisGetAPIResponseData,
        V2ApisGetAPIResponseDataTypedDict,
    )
    from .v2apislistkeysrequestbody import (
        V2ApisListKeysRequestBody,
        V2ApisListKeysRequestBodyTypedDict,
    )
    from .v2apislistkeysresponsebody import (
        V2ApisListKeysResponseBody,
        V2ApisListKeysResponseBodyTypedDict,
    )
    from .v2identitiescreateidentityrequestbody import (
        V2IdentitiesCreateIdentityRequestBody,
        V2IdentitiesCreateIdentityRequestBodyTypedDict,
    )
    from .v2identitiescreateidentityresponsebody import (
        V2IdentitiesCreateIdentityResponseBody,
        V2IdentitiesCreateIdentityResponseBodyTypedDict,
    )
    from .v2identitiescreateidentityresponsedata import (
        V2IdentitiesCreateIdentityResponseData,
        V2IdentitiesCreateIdentityResponseDataTypedDict,
    )
    from .v2identitiesdeleteidentityrequestbody import (
        V2IdentitiesDeleteIdentityRequestBody,
        V2IdentitiesDeleteIdentityRequestBodyTypedDict,
    )
    from .v2identitiesdeleteidentityresponsebody import (
        V2IdentitiesDeleteIdentityResponseBody,
        V2IdentitiesDeleteIdentityResponseBodyTypedDict,
    )
    from .v2identitiesgetidentityrequestbody import (
        V2IdentitiesGetIdentityRequestBody,
        V2IdentitiesGetIdentityRequestBodyTypedDict,
    )
    from .v2identitiesgetidentityresponsebody import (
        V2IdentitiesGetIdentityResponseBody,
        V2IdentitiesGetIdentityResponseBodyTypedDict,
    )
    from .v2identitiesgetidentityresponsedata import (
        V2IdentitiesGetIdentityResponseData,
        V2IdentitiesGetIdentityResponseDataTypedDict,
    )
    from .v2identitieslistidentitiesrequestbody import (
        V2IdentitiesListIdentitiesRequestBody,
        V2IdentitiesListIdentitiesRequestBodyTypedDict,
    )
    from .v2identitieslistidentitiesresponsebody import (
        V2IdentitiesListIdentitiesResponseBody,
        V2IdentitiesListIdentitiesResponseBodyTypedDict,
    )
    from .v2identitiesupdateidentityrequestbody import (
        V2IdentitiesUpdateIdentityRequestBody,
        V2IdentitiesUpdateIdentityRequestBodyTypedDict,
    )
    from .v2identitiesupdateidentityresponsebody import (
        V2IdentitiesUpdateIdentityResponseBody,
        V2IdentitiesUpdateIdentityResponseBodyTypedDict,
    )
    from .v2keysaddpermissionsrequestbody import (
        V2KeysAddPermissionsRequestBody,
        V2KeysAddPermissionsRequestBodyTypedDict,
    )
    from .v2keysaddpermissionsresponsebody import (
        V2KeysAddPermissionsResponseBody,
        V2KeysAddPermissionsResponseBodyTypedDict,
    )
    from .v2keysaddrolesrequestbody import (
        V2KeysAddRolesRequestBody,
        V2KeysAddRolesRequestBodyTypedDict,
    )
    from .v2keysaddrolesresponsebody import (
        V2KeysAddRolesResponseBody,
        V2KeysAddRolesResponseBodyTypedDict,
    )
    from .v2keyscreatekeyrequestbody import (
        V2KeysCreateKeyRequestBody,
        V2KeysCreateKeyRequestBodyTypedDict,
    )
    from .v2keyscreatekeyresponsebody import (
        V2KeysCreateKeyResponseBody,
        V2KeysCreateKeyResponseBodyTypedDict,
    )
    from .v2keyscreatekeyresponsedata import (
        V2KeysCreateKeyResponseData,
        V2KeysCreateKeyResponseDataTypedDict,
    )
    from .v2keysdeletekeyrequestbody import (
        V2KeysDeleteKeyRequestBody,
        V2KeysDeleteKeyRequestBodyTypedDict,
    )
    from .v2keysdeletekeyresponsebody import (
        V2KeysDeleteKeyResponseBody,
        V2KeysDeleteKeyResponseBodyTypedDict,
    )
    from .v2keysgetkeyrequestbody import (
        V2KeysGetKeyRequestBody,
        V2KeysGetKeyRequestBodyTypedDict,
    )
    from .v2keysgetkeyresponsebody import (
        V2KeysGetKeyResponseBody,
        V2KeysGetKeyResponseBodyTypedDict,
    )
    from .v2keysremovepermissionsrequestbody import (
        V2KeysRemovePermissionsRequestBody,
        V2KeysRemovePermissionsRequestBodyTypedDict,
    )
    from .v2keysremovepermissionsresponsebody import (
        V2KeysRemovePermissionsResponseBody,
        V2KeysRemovePermissionsResponseBodyTypedDict,
    )
    from .v2keysremoverolesrequestbody import (
        V2KeysRemoveRolesRequestBody,
        V2KeysRemoveRolesRequestBodyTypedDict,
    )
    from .v2keysremoverolesresponsebody import (
        V2KeysRemoveRolesResponseBody,
        V2KeysRemoveRolesResponseBodyTypedDict,
    )
    from .v2keyssetpermissionsrequestbody import (
        V2KeysSetPermissionsRequestBody,
        V2KeysSetPermissionsRequestBodyTypedDict,
    )
    from .v2keyssetpermissionsresponsebody import (
        V2KeysSetPermissionsResponseBody,
        V2KeysSetPermissionsResponseBodyTypedDict,
    )
    from .v2keyssetrolesrequestbody import (
        V2KeysSetRolesRequestBody,
        V2KeysSetRolesRequestBodyTypedDict,
    )
    from .v2keyssetrolesresponsebody import (
        V2KeysSetRolesResponseBody,
        V2KeysSetRolesResponseBodyTypedDict,
    )
    from .v2keysupdatecreditsrequestbody import (
        Operation,
        V2KeysUpdateCreditsRequestBody,
        V2KeysUpdateCreditsRequestBodyTypedDict,
    )
    from .v2keysupdatecreditsresponsebody import (
        V2KeysUpdateCreditsResponseBody,
        V2KeysUpdateCreditsResponseBodyTypedDict,
    )
    from .v2keysupdatekeyrequestbody import (
        V2KeysUpdateKeyRequestBody,
        V2KeysUpdateKeyRequestBodyTypedDict,
    )
    from .v2keysupdatekeyresponsebody import (
        V2KeysUpdateKeyResponseBody,
        V2KeysUpdateKeyResponseBodyTypedDict,
    )
    from .v2keysverifykeyrequestbody import (
        V2KeysVerifyKeyRequestBody,
        V2KeysVerifyKeyRequestBodyTypedDict,
    )
    from .v2keysverifykeyresponsebody import (
        V2KeysVerifyKeyResponseBody,
        V2KeysVerifyKeyResponseBodyTypedDict,
    )
    from .v2keysverifykeyresponsedata import (
        Code,
        V2KeysVerifyKeyResponseData,
        V2KeysVerifyKeyResponseDataTypedDict,
    )
    from .v2keyswhoamirequestbody import (
        V2KeysWhoamiRequestBody,
        V2KeysWhoamiRequestBodyTypedDict,
    )
    from .v2keyswhoamiresponsebody import (
        V2KeysWhoamiResponseBody,
        V2KeysWhoamiResponseBodyTypedDict,
    )
    from .v2permissionscreatepermissionrequestbody import (
        V2PermissionsCreatePermissionRequestBody,
        V2PermissionsCreatePermissionRequestBodyTypedDict,
    )
    from .v2permissionscreatepermissionresponsebody import (
        V2PermissionsCreatePermissionResponseBody,
        V2PermissionsCreatePermissionResponseBodyTypedDict,
    )
    from .v2permissionscreatepermissionresponsedata import (
        V2PermissionsCreatePermissionResponseData,
        V2PermissionsCreatePermissionResponseDataTypedDict,
    )
    from .v2permissionscreaterolerequestbody import (
        V2PermissionsCreateRoleRequestBody,
        V2PermissionsCreateRoleRequestBodyTypedDict,
    )
    from .v2permissionscreateroleresponsebody import (
        V2PermissionsCreateRoleResponseBody,
        V2PermissionsCreateRoleResponseBodyTypedDict,
    )
    from .v2permissionscreateroleresponsedata import (
        V2PermissionsCreateRoleResponseData,
        V2PermissionsCreateRoleResponseDataTypedDict,
    )
    from .v2permissionsdeletepermissionrequestbody import (
        V2PermissionsDeletePermissionRequestBody,
        V2PermissionsDeletePermissionRequestBodyTypedDict,
    )
    from .v2permissionsdeletepermissionresponsebody import (
        V2PermissionsDeletePermissionResponseBody,
        V2PermissionsDeletePermissionResponseBodyTypedDict,
    )
    from .v2permissionsdeleterolerequestbody import (
        V2PermissionsDeleteRoleRequestBody,
        V2PermissionsDeleteRoleRequestBodyTypedDict,
    )
    from .v2permissionsdeleteroleresponsebody import (
        V2PermissionsDeleteRoleResponseBody,
        V2PermissionsDeleteRoleResponseBodyTypedDict,
    )
    from .v2permissionsgetpermissionrequestbody import (
        V2PermissionsGetPermissionRequestBody,
        V2PermissionsGetPermissionRequestBodyTypedDict,
    )
    from .v2permissionsgetpermissionresponsebody import (
        V2PermissionsGetPermissionResponseBody,
        V2PermissionsGetPermissionResponseBodyTypedDict,
    )
    from .v2permissionsgetpermissionresponsedata import (
        V2PermissionsGetPermissionResponseData,
        V2PermissionsGetPermissionResponseDataTypedDict,
    )
    from .v2permissionsgetrolerequestbody import (
        V2PermissionsGetRoleRequestBody,
        V2PermissionsGetRoleRequestBodyTypedDict,
    )
    from .v2permissionsgetroleresponsebody import (
        V2PermissionsGetRoleResponseBody,
        V2PermissionsGetRoleResponseBodyTypedDict,
    )
    from .v2permissionsgetroleresponsedata import (
        V2PermissionsGetRoleResponseData,
        V2PermissionsGetRoleResponseDataTypedDict,
    )
    from .v2permissionslistpermissionsrequestbody import (
        V2PermissionsListPermissionsRequestBody,
        V2PermissionsListPermissionsRequestBodyTypedDict,
    )
    from .v2permissionslistpermissionsresponsebody import (
        V2PermissionsListPermissionsResponseBody,
        V2PermissionsListPermissionsResponseBodyTypedDict,
    )
    from .v2permissionslistrolesrequestbody import (
        V2PermissionsListRolesRequestBody,
        V2PermissionsListRolesRequestBodyTypedDict,
    )
    from .v2permissionslistrolesresponsebody import (
        V2PermissionsListRolesResponseBody,
        V2PermissionsListRolesResponseBodyTypedDict,
    )
    from .v2ratelimitdeleteoverriderequestbody import (
        V2RatelimitDeleteOverrideRequestBody,
        V2RatelimitDeleteOverrideRequestBodyTypedDict,
    )
    from .v2ratelimitdeleteoverrideresponsebody import (
        V2RatelimitDeleteOverrideResponseBody,
        V2RatelimitDeleteOverrideResponseBodyTypedDict,
    )
    from .v2ratelimitdeleteoverrideresponsedata import (
        V2RatelimitDeleteOverrideResponseData,
        V2RatelimitDeleteOverrideResponseDataTypedDict,
    )
    from .v2ratelimitgetoverriderequestbody import (
        V2RatelimitGetOverrideRequestBody,
        V2RatelimitGetOverrideRequestBodyTypedDict,
    )
    from .v2ratelimitgetoverrideresponsebody import (
        V2RatelimitGetOverrideResponseBody,
        V2RatelimitGetOverrideResponseBodyTypedDict,
    )
    from .v2ratelimitlimitrequestbody import (
        V2RatelimitLimitRequestBody,
        V2RatelimitLimitRequestBodyTypedDict,
    )
    from .v2ratelimitlimitresponsebody import (
        V2RatelimitLimitResponseBody,
        V2RatelimitLimitResponseBodyTypedDict,
    )
    from .v2ratelimitlimitresponsedata import (
        V2RatelimitLimitResponseData,
        V2RatelimitLimitResponseDataTypedDict,
    )
    from .v2ratelimitlistoverridesrequestbody import (
        V2RatelimitListOverridesRequestBody,
        V2RatelimitListOverridesRequestBodyTypedDict,
    )
    from .v2ratelimitlistoverridesresponsebody import (
        V2RatelimitListOverridesResponseBody,
        V2RatelimitListOverridesResponseBodyTypedDict,
    )
    from .v2ratelimitsetoverriderequestbody import (
        V2RatelimitSetOverrideRequestBody,
        V2RatelimitSetOverrideRequestBodyTypedDict,
    )
    from .v2ratelimitsetoverrideresponsebody import (
        V2RatelimitSetOverrideResponseBody,
        V2RatelimitSetOverrideResponseBodyTypedDict,
    )
    from .v2ratelimitsetoverrideresponsedata import (
        V2RatelimitSetOverrideResponseData,
        V2RatelimitSetOverrideResponseDataTypedDict,
    )
    from .validationerror import ValidationError, ValidationErrorTypedDict
    from .verifykeyratelimitdata import (
        VerifyKeyRatelimitData,
        VerifyKeyRatelimitDataTypedDict,
    )

__all__ = [
    "BadRequestErrorDetails",
    "BadRequestErrorDetailsTypedDict",
    "BaseError",
    "BaseErrorTypedDict",
    "Code",
    "EmptyResponse",
    "EmptyResponseTypedDict",
    "IdentitiesListIdentitiesResponse",
    "IdentitiesListIdentitiesResponseTypedDict",
    "Identity",
    "IdentityMeta",
    "IdentityMetaTypedDict",
    "IdentityTypedDict",
    "Interval",
    "KeyCreditsData",
    "KeyCreditsDataTypedDict",
    "KeyCreditsRefill",
    "KeyCreditsRefillTypedDict",
    "KeyResponseData",
    "KeyResponseDataTypedDict",
    "KeysVerifyKeyCredits",
    "KeysVerifyKeyCreditsTypedDict",
    "KeysVerifyKeyRatelimit",
    "KeysVerifyKeyRatelimitTypedDict",
    "Meta",
    "MetaTypedDict",
    "Operation",
    "Pagination",
    "PaginationTypedDict",
    "Permission",
    "PermissionTypedDict",
    "RatelimitOverride",
    "RatelimitOverrideTypedDict",
    "RatelimitRequest",
    "RatelimitRequestTypedDict",
    "RatelimitResponse",
    "RatelimitResponseTypedDict",
    "Role",
    "RoleTypedDict",
    "Security",
    "SecurityTypedDict",
    "V2ApisCreateAPIRequestBody",
    "V2ApisCreateAPIRequestBodyTypedDict",
    "V2ApisCreateAPIResponseBody",
    "V2ApisCreateAPIResponseBodyTypedDict",
    "V2ApisCreateAPIResponseData",
    "V2ApisCreateAPIResponseDataTypedDict",
    "V2ApisDeleteAPIRequestBody",
    "V2ApisDeleteAPIRequestBodyTypedDict",
    "V2ApisDeleteAPIResponseBody",
    "V2ApisDeleteAPIResponseBodyTypedDict",
    "V2ApisGetAPIRequestBody",
    "V2ApisGetAPIRequestBodyTypedDict",
    "V2ApisGetAPIResponseBody",
    "V2ApisGetAPIResponseBodyTypedDict",
    "V2ApisGetAPIResponseData",
    "V2ApisGetAPIResponseDataTypedDict",
    "V2ApisListKeysRequestBody",
    "V2ApisListKeysRequestBodyTypedDict",
    "V2ApisListKeysResponseBody",
    "V2ApisListKeysResponseBodyTypedDict",
    "V2IdentitiesCreateIdentityRequestBody",
    "V2IdentitiesCreateIdentityRequestBodyTypedDict",
    "V2IdentitiesCreateIdentityResponseBody",
    "V2IdentitiesCreateIdentityResponseBodyTypedDict",
    "V2IdentitiesCreateIdentityResponseData",
    "V2IdentitiesCreateIdentityResponseDataTypedDict",
    "V2IdentitiesDeleteIdentityRequestBody",
    "V2IdentitiesDeleteIdentityRequestBodyTypedDict",
    "V2IdentitiesDeleteIdentityResponseBody",
    "V2IdentitiesDeleteIdentityResponseBodyTypedDict",
    "V2IdentitiesGetIdentityRequestBody",
    "V2IdentitiesGetIdentityRequestBodyTypedDict",
    "V2IdentitiesGetIdentityResponseBody",
    "V2IdentitiesGetIdentityResponseBodyTypedDict",
    "V2IdentitiesGetIdentityResponseData",
    "V2IdentitiesGetIdentityResponseDataTypedDict",
    "V2IdentitiesListIdentitiesRequestBody",
    "V2IdentitiesListIdentitiesRequestBodyTypedDict",
    "V2IdentitiesListIdentitiesResponseBody",
    "V2IdentitiesListIdentitiesResponseBodyTypedDict",
    "V2IdentitiesUpdateIdentityRequestBody",
    "V2IdentitiesUpdateIdentityRequestBodyTypedDict",
    "V2IdentitiesUpdateIdentityResponseBody",
    "V2IdentitiesUpdateIdentityResponseBodyTypedDict",
    "V2KeysAddPermissionsRequestBody",
    "V2KeysAddPermissionsRequestBodyTypedDict",
    "V2KeysAddPermissionsResponseBody",
    "V2KeysAddPermissionsResponseBodyTypedDict",
    "V2KeysAddRolesRequestBody",
    "V2KeysAddRolesRequestBodyTypedDict",
    "V2KeysAddRolesResponseBody",
    "V2KeysAddRolesResponseBodyTypedDict",
    "V2KeysCreateKeyRequestBody",
    "V2KeysCreateKeyRequestBodyTypedDict",
    "V2KeysCreateKeyResponseBody",
    "V2KeysCreateKeyResponseBodyTypedDict",
    "V2KeysCreateKeyResponseData",
    "V2KeysCreateKeyResponseDataTypedDict",
    "V2KeysDeleteKeyRequestBody",
    "V2KeysDeleteKeyRequestBodyTypedDict",
    "V2KeysDeleteKeyResponseBody",
    "V2KeysDeleteKeyResponseBodyTypedDict",
    "V2KeysGetKeyRequestBody",
    "V2KeysGetKeyRequestBodyTypedDict",
    "V2KeysGetKeyResponseBody",
    "V2KeysGetKeyResponseBodyTypedDict",
    "V2KeysRemovePermissionsRequestBody",
    "V2KeysRemovePermissionsRequestBodyTypedDict",
    "V2KeysRemovePermissionsResponseBody",
    "V2KeysRemovePermissionsResponseBodyTypedDict",
    "V2KeysRemoveRolesRequestBody",
    "V2KeysRemoveRolesRequestBodyTypedDict",
    "V2KeysRemoveRolesResponseBody",
    "V2KeysRemoveRolesResponseBodyTypedDict",
    "V2KeysSetPermissionsRequestBody",
    "V2KeysSetPermissionsRequestBodyTypedDict",
    "V2KeysSetPermissionsResponseBody",
    "V2KeysSetPermissionsResponseBodyTypedDict",
    "V2KeysSetRolesRequestBody",
    "V2KeysSetRolesRequestBodyTypedDict",
    "V2KeysSetRolesResponseBody",
    "V2KeysSetRolesResponseBodyTypedDict",
    "V2KeysUpdateCreditsRequestBody",
    "V2KeysUpdateCreditsRequestBodyTypedDict",
    "V2KeysUpdateCreditsResponseBody",
    "V2KeysUpdateCreditsResponseBodyTypedDict",
    "V2KeysUpdateKeyRequestBody",
    "V2KeysUpdateKeyRequestBodyTypedDict",
    "V2KeysUpdateKeyResponseBody",
    "V2KeysUpdateKeyResponseBodyTypedDict",
    "V2KeysVerifyKeyRequestBody",
    "V2KeysVerifyKeyRequestBodyTypedDict",
    "V2KeysVerifyKeyResponseBody",
    "V2KeysVerifyKeyResponseBodyTypedDict",
    "V2KeysVerifyKeyResponseData",
    "V2KeysVerifyKeyResponseDataTypedDict",
    "V2KeysWhoamiRequestBody",
    "V2KeysWhoamiRequestBodyTypedDict",
    "V2KeysWhoamiResponseBody",
    "V2KeysWhoamiResponseBodyTypedDict",
    "V2PermissionsCreatePermissionRequestBody",
    "V2PermissionsCreatePermissionRequestBodyTypedDict",
    "V2PermissionsCreatePermissionResponseBody",
    "V2PermissionsCreatePermissionResponseBodyTypedDict",
    "V2PermissionsCreatePermissionResponseData",
    "V2PermissionsCreatePermissionResponseDataTypedDict",
    "V2PermissionsCreateRoleRequestBody",
    "V2PermissionsCreateRoleRequestBodyTypedDict",
    "V2PermissionsCreateRoleResponseBody",
    "V2PermissionsCreateRoleResponseBodyTypedDict",
    "V2PermissionsCreateRoleResponseData",
    "V2PermissionsCreateRoleResponseDataTypedDict",
    "V2PermissionsDeletePermissionRequestBody",
    "V2PermissionsDeletePermissionRequestBodyTypedDict",
    "V2PermissionsDeletePermissionResponseBody",
    "V2PermissionsDeletePermissionResponseBodyTypedDict",
    "V2PermissionsDeleteRoleRequestBody",
    "V2PermissionsDeleteRoleRequestBodyTypedDict",
    "V2PermissionsDeleteRoleResponseBody",
    "V2PermissionsDeleteRoleResponseBodyTypedDict",
    "V2PermissionsGetPermissionRequestBody",
    "V2PermissionsGetPermissionRequestBodyTypedDict",
    "V2PermissionsGetPermissionResponseBody",
    "V2PermissionsGetPermissionResponseBodyTypedDict",
    "V2PermissionsGetPermissionResponseData",
    "V2PermissionsGetPermissionResponseDataTypedDict",
    "V2PermissionsGetRoleRequestBody",
    "V2PermissionsGetRoleRequestBodyTypedDict",
    "V2PermissionsGetRoleResponseBody",
    "V2PermissionsGetRoleResponseBodyTypedDict",
    "V2PermissionsGetRoleResponseData",
    "V2PermissionsGetRoleResponseDataTypedDict",
    "V2PermissionsListPermissionsRequestBody",
    "V2PermissionsListPermissionsRequestBodyTypedDict",
    "V2PermissionsListPermissionsResponseBody",
    "V2PermissionsListPermissionsResponseBodyTypedDict",
    "V2PermissionsListRolesRequestBody",
    "V2PermissionsListRolesRequestBodyTypedDict",
    "V2PermissionsListRolesResponseBody",
    "V2PermissionsListRolesResponseBodyTypedDict",
    "V2RatelimitDeleteOverrideRequestBody",
    "V2RatelimitDeleteOverrideRequestBodyTypedDict",
    "V2RatelimitDeleteOverrideResponseBody",
    "V2RatelimitDeleteOverrideResponseBodyTypedDict",
    "V2RatelimitDeleteOverrideResponseData",
    "V2RatelimitDeleteOverrideResponseDataTypedDict",
    "V2RatelimitGetOverrideRequestBody",
    "V2RatelimitGetOverrideRequestBodyTypedDict",
    "V2RatelimitGetOverrideResponseBody",
    "V2RatelimitGetOverrideResponseBodyTypedDict",
    "V2RatelimitLimitRequestBody",
    "V2RatelimitLimitRequestBodyTypedDict",
    "V2RatelimitLimitResponseBody",
    "V2RatelimitLimitResponseBodyTypedDict",
    "V2RatelimitLimitResponseData",
    "V2RatelimitLimitResponseDataTypedDict",
    "V2RatelimitListOverridesRequestBody",
    "V2RatelimitListOverridesRequestBodyTypedDict",
    "V2RatelimitListOverridesResponseBody",
    "V2RatelimitListOverridesResponseBodyTypedDict",
    "V2RatelimitSetOverrideRequestBody",
    "V2RatelimitSetOverrideRequestBodyTypedDict",
    "V2RatelimitSetOverrideResponseBody",
    "V2RatelimitSetOverrideResponseBodyTypedDict",
    "V2RatelimitSetOverrideResponseData",
    "V2RatelimitSetOverrideResponseDataTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "VerifyKeyRatelimitData",
    "VerifyKeyRatelimitDataTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "BadRequestErrorDetails": ".badrequesterrordetails",
    "BadRequestErrorDetailsTypedDict": ".badrequesterrordetails",
    "BaseError": ".baseerror",
    "BaseErrorTypedDict": ".baseerror",
    "EmptyResponse": ".emptyresponse",
    "EmptyResponseTypedDict": ".emptyresponse",
    "IdentitiesListIdentitiesResponse": ".identities_listidentitiesop",
    "IdentitiesListIdentitiesResponseTypedDict": ".identities_listidentitiesop",
    "Identity": ".identity",
    "IdentityMeta": ".identity",
    "IdentityMetaTypedDict": ".identity",
    "IdentityTypedDict": ".identity",
    "KeyCreditsData": ".keycreditsdata",
    "KeyCreditsDataTypedDict": ".keycreditsdata",
    "Interval": ".keycreditsrefill",
    "KeyCreditsRefill": ".keycreditsrefill",
    "KeyCreditsRefillTypedDict": ".keycreditsrefill",
    "KeyResponseData": ".keyresponsedata",
    "KeyResponseDataTypedDict": ".keyresponsedata",
    "KeysVerifyKeyCredits": ".keysverifykeycredits",
    "KeysVerifyKeyCreditsTypedDict": ".keysverifykeycredits",
    "KeysVerifyKeyRatelimit": ".keysverifykeyratelimit",
    "KeysVerifyKeyRatelimitTypedDict": ".keysverifykeyratelimit",
    "Meta": ".meta",
    "MetaTypedDict": ".meta",
    "Pagination": ".pagination",
    "PaginationTypedDict": ".pagination",
    "Permission": ".permission",
    "PermissionTypedDict": ".permission",
    "RatelimitOverride": ".ratelimitoverride",
    "RatelimitOverrideTypedDict": ".ratelimitoverride",
    "RatelimitRequest": ".ratelimitrequest",
    "RatelimitRequestTypedDict": ".ratelimitrequest",
    "RatelimitResponse": ".ratelimitresponse",
    "RatelimitResponseTypedDict": ".ratelimitresponse",
    "Role": ".role",
    "RoleTypedDict": ".role",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "V2ApisCreateAPIRequestBody": ".v2apiscreateapirequestbody",
    "V2ApisCreateAPIRequestBodyTypedDict": ".v2apiscreateapirequestbody",
    "V2ApisCreateAPIResponseBody": ".v2apiscreateapiresponsebody",
    "V2ApisCreateAPIResponseBodyTypedDict": ".v2apiscreateapiresponsebody",
    "V2ApisCreateAPIResponseData": ".v2apiscreateapiresponsedata",
    "V2ApisCreateAPIResponseDataTypedDict": ".v2apiscreateapiresponsedata",
    "V2ApisDeleteAPIRequestBody": ".v2apisdeleteapirequestbody",
    "V2ApisDeleteAPIRequestBodyTypedDict": ".v2apisdeleteapirequestbody",
    "V2ApisDeleteAPIResponseBody": ".v2apisdeleteapiresponsebody",
    "V2ApisDeleteAPIResponseBodyTypedDict": ".v2apisdeleteapiresponsebody",
    "V2ApisGetAPIRequestBody": ".v2apisgetapirequestbody",
    "V2ApisGetAPIRequestBodyTypedDict": ".v2apisgetapirequestbody",
    "V2ApisGetAPIResponseBody": ".v2apisgetapiresponsebody",
    "V2ApisGetAPIResponseBodyTypedDict": ".v2apisgetapiresponsebody",
    "V2ApisGetAPIResponseData": ".v2apisgetapiresponsedata",
    "V2ApisGetAPIResponseDataTypedDict": ".v2apisgetapiresponsedata",
    "V2ApisListKeysRequestBody": ".v2apislistkeysrequestbody",
    "V2ApisListKeysRequestBodyTypedDict": ".v2apislistkeysrequestbody",
    "V2ApisListKeysResponseBody": ".v2apislistkeysresponsebody",
    "V2ApisListKeysResponseBodyTypedDict": ".v2apislistkeysresponsebody",
    "V2IdentitiesCreateIdentityRequestBody": ".v2identitiescreateidentityrequestbody",
    "V2IdentitiesCreateIdentityRequestBodyTypedDict": ".v2identitiescreateidentityrequestbody",
    "V2IdentitiesCreateIdentityResponseBody": ".v2identitiescreateidentityresponsebody",
    "V2IdentitiesCreateIdentityResponseBodyTypedDict": ".v2identitiescreateidentityresponsebody",
    "V2IdentitiesCreateIdentityResponseData": ".v2identitiescreateidentityresponsedata",
    "V2IdentitiesCreateIdentityResponseDataTypedDict": ".v2identitiescreateidentityresponsedata",
    "V2IdentitiesDeleteIdentityRequestBody": ".v2identitiesdeleteidentityrequestbody",
    "V2IdentitiesDeleteIdentityRequestBodyTypedDict": ".v2identitiesdeleteidentityrequestbody",
    "V2IdentitiesDeleteIdentityResponseBody": ".v2identitiesdeleteidentityresponsebody",
    "V2IdentitiesDeleteIdentityResponseBodyTypedDict": ".v2identitiesdeleteidentityresponsebody",
    "V2IdentitiesGetIdentityRequestBody": ".v2identitiesgetidentityrequestbody",
    "V2IdentitiesGetIdentityRequestBodyTypedDict": ".v2identitiesgetidentityrequestbody",
    "V2IdentitiesGetIdentityResponseBody": ".v2identitiesgetidentityresponsebody",
    "V2IdentitiesGetIdentityResponseBodyTypedDict": ".v2identitiesgetidentityresponsebody",
    "V2IdentitiesGetIdentityResponseData": ".v2identitiesgetidentityresponsedata",
    "V2IdentitiesGetIdentityResponseDataTypedDict": ".v2identitiesgetidentityresponsedata",
    "V2IdentitiesListIdentitiesRequestBody": ".v2identitieslistidentitiesrequestbody",
    "V2IdentitiesListIdentitiesRequestBodyTypedDict": ".v2identitieslistidentitiesrequestbody",
    "V2IdentitiesListIdentitiesResponseBody": ".v2identitieslistidentitiesresponsebody",
    "V2IdentitiesListIdentitiesResponseBodyTypedDict": ".v2identitieslistidentitiesresponsebody",
    "V2IdentitiesUpdateIdentityRequestBody": ".v2identitiesupdateidentityrequestbody",
    "V2IdentitiesUpdateIdentityRequestBodyTypedDict": ".v2identitiesupdateidentityrequestbody",
    "V2IdentitiesUpdateIdentityResponseBody": ".v2identitiesupdateidentityresponsebody",
    "V2IdentitiesUpdateIdentityResponseBodyTypedDict": ".v2identitiesupdateidentityresponsebody",
    "V2KeysAddPermissionsRequestBody": ".v2keysaddpermissionsrequestbody",
    "V2KeysAddPermissionsRequestBodyTypedDict": ".v2keysaddpermissionsrequestbody",
    "V2KeysAddPermissionsResponseBody": ".v2keysaddpermissionsresponsebody",
    "V2KeysAddPermissionsResponseBodyTypedDict": ".v2keysaddpermissionsresponsebody",
    "V2KeysAddRolesRequestBody": ".v2keysaddrolesrequestbody",
    "V2KeysAddRolesRequestBodyTypedDict": ".v2keysaddrolesrequestbody",
    "V2KeysAddRolesResponseBody": ".v2keysaddrolesresponsebody",
    "V2KeysAddRolesResponseBodyTypedDict": ".v2keysaddrolesresponsebody",
    "V2KeysCreateKeyRequestBody": ".v2keyscreatekeyrequestbody",
    "V2KeysCreateKeyRequestBodyTypedDict": ".v2keyscreatekeyrequestbody",
    "V2KeysCreateKeyResponseBody": ".v2keyscreatekeyresponsebody",
    "V2KeysCreateKeyResponseBodyTypedDict": ".v2keyscreatekeyresponsebody",
    "V2KeysCreateKeyResponseData": ".v2keyscreatekeyresponsedata",
    "V2KeysCreateKeyResponseDataTypedDict": ".v2keyscreatekeyresponsedata",
    "V2KeysDeleteKeyRequestBody": ".v2keysdeletekeyrequestbody",
    "V2KeysDeleteKeyRequestBodyTypedDict": ".v2keysdeletekeyrequestbody",
    "V2KeysDeleteKeyResponseBody": ".v2keysdeletekeyresponsebody",
    "V2KeysDeleteKeyResponseBodyTypedDict": ".v2keysdeletekeyresponsebody",
    "V2KeysGetKeyRequestBody": ".v2keysgetkeyrequestbody",
    "V2KeysGetKeyRequestBodyTypedDict": ".v2keysgetkeyrequestbody",
    "V2KeysGetKeyResponseBody": ".v2keysgetkeyresponsebody",
    "V2KeysGetKeyResponseBodyTypedDict": ".v2keysgetkeyresponsebody",
    "V2KeysRemovePermissionsRequestBody": ".v2keysremovepermissionsrequestbody",
    "V2KeysRemovePermissionsRequestBodyTypedDict": ".v2keysremovepermissionsrequestbody",
    "V2KeysRemovePermissionsResponseBody": ".v2keysremovepermissionsresponsebody",
    "V2KeysRemovePermissionsResponseBodyTypedDict": ".v2keysremovepermissionsresponsebody",
    "V2KeysRemoveRolesRequestBody": ".v2keysremoverolesrequestbody",
    "V2KeysRemoveRolesRequestBodyTypedDict": ".v2keysremoverolesrequestbody",
    "V2KeysRemoveRolesResponseBody": ".v2keysremoverolesresponsebody",
    "V2KeysRemoveRolesResponseBodyTypedDict": ".v2keysremoverolesresponsebody",
    "V2KeysSetPermissionsRequestBody": ".v2keyssetpermissionsrequestbody",
    "V2KeysSetPermissionsRequestBodyTypedDict": ".v2keyssetpermissionsrequestbody",
    "V2KeysSetPermissionsResponseBody": ".v2keyssetpermissionsresponsebody",
    "V2KeysSetPermissionsResponseBodyTypedDict": ".v2keyssetpermissionsresponsebody",
    "V2KeysSetRolesRequestBody": ".v2keyssetrolesrequestbody",
    "V2KeysSetRolesRequestBodyTypedDict": ".v2keyssetrolesrequestbody",
    "V2KeysSetRolesResponseBody": ".v2keyssetrolesresponsebody",
    "V2KeysSetRolesResponseBodyTypedDict": ".v2keyssetrolesresponsebody",
    "Operation": ".v2keysupdatecreditsrequestbody",
    "V2KeysUpdateCreditsRequestBody": ".v2keysupdatecreditsrequestbody",
    "V2KeysUpdateCreditsRequestBodyTypedDict": ".v2keysupdatecreditsrequestbody",
    "V2KeysUpdateCreditsResponseBody": ".v2keysupdatecreditsresponsebody",
    "V2KeysUpdateCreditsResponseBodyTypedDict": ".v2keysupdatecreditsresponsebody",
    "V2KeysUpdateKeyRequestBody": ".v2keysupdatekeyrequestbody",
    "V2KeysUpdateKeyRequestBodyTypedDict": ".v2keysupdatekeyrequestbody",
    "V2KeysUpdateKeyResponseBody": ".v2keysupdatekeyresponsebody",
    "V2KeysUpdateKeyResponseBodyTypedDict": ".v2keysupdatekeyresponsebody",
    "V2KeysVerifyKeyRequestBody": ".v2keysverifykeyrequestbody",
    "V2KeysVerifyKeyRequestBodyTypedDict": ".v2keysverifykeyrequestbody",
    "V2KeysVerifyKeyResponseBody": ".v2keysverifykeyresponsebody",
    "V2KeysVerifyKeyResponseBodyTypedDict": ".v2keysverifykeyresponsebody",
    "Code": ".v2keysverifykeyresponsedata",
    "V2KeysVerifyKeyResponseData": ".v2keysverifykeyresponsedata",
    "V2KeysVerifyKeyResponseDataTypedDict": ".v2keysverifykeyresponsedata",
    "V2KeysWhoamiRequestBody": ".v2keyswhoamirequestbody",
    "V2KeysWhoamiRequestBodyTypedDict": ".v2keyswhoamirequestbody",
    "V2KeysWhoamiResponseBody": ".v2keyswhoamiresponsebody",
    "V2KeysWhoamiResponseBodyTypedDict": ".v2keyswhoamiresponsebody",
    "V2PermissionsCreatePermissionRequestBody": ".v2permissionscreatepermissionrequestbody",
    "V2PermissionsCreatePermissionRequestBodyTypedDict": ".v2permissionscreatepermissionrequestbody",
    "V2PermissionsCreatePermissionResponseBody": ".v2permissionscreatepermissionresponsebody",
    "V2PermissionsCreatePermissionResponseBodyTypedDict": ".v2permissionscreatepermissionresponsebody",
    "V2PermissionsCreatePermissionResponseData": ".v2permissionscreatepermissionresponsedata",
    "V2PermissionsCreatePermissionResponseDataTypedDict": ".v2permissionscreatepermissionresponsedata",
    "V2PermissionsCreateRoleRequestBody": ".v2permissionscreaterolerequestbody",
    "V2PermissionsCreateRoleRequestBodyTypedDict": ".v2permissionscreaterolerequestbody",
    "V2PermissionsCreateRoleResponseBody": ".v2permissionscreateroleresponsebody",
    "V2PermissionsCreateRoleResponseBodyTypedDict": ".v2permissionscreateroleresponsebody",
    "V2PermissionsCreateRoleResponseData": ".v2permissionscreateroleresponsedata",
    "V2PermissionsCreateRoleResponseDataTypedDict": ".v2permissionscreateroleresponsedata",
    "V2PermissionsDeletePermissionRequestBody": ".v2permissionsdeletepermissionrequestbody",
    "V2PermissionsDeletePermissionRequestBodyTypedDict": ".v2permissionsdeletepermissionrequestbody",
    "V2PermissionsDeletePermissionResponseBody": ".v2permissionsdeletepermissionresponsebody",
    "V2PermissionsDeletePermissionResponseBodyTypedDict": ".v2permissionsdeletepermissionresponsebody",
    "V2PermissionsDeleteRoleRequestBody": ".v2permissionsdeleterolerequestbody",
    "V2PermissionsDeleteRoleRequestBodyTypedDict": ".v2permissionsdeleterolerequestbody",
    "V2PermissionsDeleteRoleResponseBody": ".v2permissionsdeleteroleresponsebody",
    "V2PermissionsDeleteRoleResponseBodyTypedDict": ".v2permissionsdeleteroleresponsebody",
    "V2PermissionsGetPermissionRequestBody": ".v2permissionsgetpermissionrequestbody",
    "V2PermissionsGetPermissionRequestBodyTypedDict": ".v2permissionsgetpermissionrequestbody",
    "V2PermissionsGetPermissionResponseBody": ".v2permissionsgetpermissionresponsebody",
    "V2PermissionsGetPermissionResponseBodyTypedDict": ".v2permissionsgetpermissionresponsebody",
    "V2PermissionsGetPermissionResponseData": ".v2permissionsgetpermissionresponsedata",
    "V2PermissionsGetPermissionResponseDataTypedDict": ".v2permissionsgetpermissionresponsedata",
    "V2PermissionsGetRoleRequestBody": ".v2permissionsgetrolerequestbody",
    "V2PermissionsGetRoleRequestBodyTypedDict": ".v2permissionsgetrolerequestbody",
    "V2PermissionsGetRoleResponseBody": ".v2permissionsgetroleresponsebody",
    "V2PermissionsGetRoleResponseBodyTypedDict": ".v2permissionsgetroleresponsebody",
    "V2PermissionsGetRoleResponseData": ".v2permissionsgetroleresponsedata",
    "V2PermissionsGetRoleResponseDataTypedDict": ".v2permissionsgetroleresponsedata",
    "V2PermissionsListPermissionsRequestBody": ".v2permissionslistpermissionsrequestbody",
    "V2PermissionsListPermissionsRequestBodyTypedDict": ".v2permissionslistpermissionsrequestbody",
    "V2PermissionsListPermissionsResponseBody": ".v2permissionslistpermissionsresponsebody",
    "V2PermissionsListPermissionsResponseBodyTypedDict": ".v2permissionslistpermissionsresponsebody",
    "V2PermissionsListRolesRequestBody": ".v2permissionslistrolesrequestbody",
    "V2PermissionsListRolesRequestBodyTypedDict": ".v2permissionslistrolesrequestbody",
    "V2PermissionsListRolesResponseBody": ".v2permissionslistrolesresponsebody",
    "V2PermissionsListRolesResponseBodyTypedDict": ".v2permissionslistrolesresponsebody",
    "V2RatelimitDeleteOverrideRequestBody": ".v2ratelimitdeleteoverriderequestbody",
    "V2RatelimitDeleteOverrideRequestBodyTypedDict": ".v2ratelimitdeleteoverriderequestbody",
    "V2RatelimitDeleteOverrideResponseBody": ".v2ratelimitdeleteoverrideresponsebody",
    "V2RatelimitDeleteOverrideResponseBodyTypedDict": ".v2ratelimitdeleteoverrideresponsebody",
    "V2RatelimitDeleteOverrideResponseData": ".v2ratelimitdeleteoverrideresponsedata",
    "V2RatelimitDeleteOverrideResponseDataTypedDict": ".v2ratelimitdeleteoverrideresponsedata",
    "V2RatelimitGetOverrideRequestBody": ".v2ratelimitgetoverriderequestbody",
    "V2RatelimitGetOverrideRequestBodyTypedDict": ".v2ratelimitgetoverriderequestbody",
    "V2RatelimitGetOverrideResponseBody": ".v2ratelimitgetoverrideresponsebody",
    "V2RatelimitGetOverrideResponseBodyTypedDict": ".v2ratelimitgetoverrideresponsebody",
    "V2RatelimitLimitRequestBody": ".v2ratelimitlimitrequestbody",
    "V2RatelimitLimitRequestBodyTypedDict": ".v2ratelimitlimitrequestbody",
    "V2RatelimitLimitResponseBody": ".v2ratelimitlimitresponsebody",
    "V2RatelimitLimitResponseBodyTypedDict": ".v2ratelimitlimitresponsebody",
    "V2RatelimitLimitResponseData": ".v2ratelimitlimitresponsedata",
    "V2RatelimitLimitResponseDataTypedDict": ".v2ratelimitlimitresponsedata",
    "V2RatelimitListOverridesRequestBody": ".v2ratelimitlistoverridesrequestbody",
    "V2RatelimitListOverridesRequestBodyTypedDict": ".v2ratelimitlistoverridesrequestbody",
    "V2RatelimitListOverridesResponseBody": ".v2ratelimitlistoverridesresponsebody",
    "V2RatelimitListOverridesResponseBodyTypedDict": ".v2ratelimitlistoverridesresponsebody",
    "V2RatelimitSetOverrideRequestBody": ".v2ratelimitsetoverriderequestbody",
    "V2RatelimitSetOverrideRequestBodyTypedDict": ".v2ratelimitsetoverriderequestbody",
    "V2RatelimitSetOverrideResponseBody": ".v2ratelimitsetoverrideresponsebody",
    "V2RatelimitSetOverrideResponseBodyTypedDict": ".v2ratelimitsetoverrideresponsebody",
    "V2RatelimitSetOverrideResponseData": ".v2ratelimitsetoverrideresponsedata",
    "V2RatelimitSetOverrideResponseDataTypedDict": ".v2ratelimitsetoverrideresponsedata",
    "ValidationError": ".validationerror",
    "ValidationErrorTypedDict": ".validationerror",
    "VerifyKeyRatelimitData": ".verifykeyratelimitdata",
    "VerifyKeyRatelimitDataTypedDict": ".verifykeyratelimitdata",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)
