"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class EmptyResponseTypedDict(TypedDict):
    r"""Empty response object by design. A successful response indicates this operation was successfully executed."""


class EmptyResponse(BaseModel):
    r"""Empty response object by design. A successful response indicates this operation was successfully executed."""
