"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .permission import Permission, PermissionTypedDict
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2PermissionsGetPermissionResponseDataTypedDict(TypedDict):
    r"""Complete permission details including ID, name, and metadata."""

    permission: PermissionTypedDict


class V2PermissionsGetPermissionResponseData(BaseModel):
    r"""Complete permission details including ID, name, and metadata."""

    permission: Permission
