"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .emptyresponse import EmptyResponse, EmptyResponseTypedDict
from .meta import Meta, MetaTypedDict
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2KeysUpdateKeyResponseBodyTypedDict(TypedDict):
    meta: MetaTypedDict
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""
    data: EmptyResponseTypedDict
    r"""Empty response object by design. A successful response indicates this operation was successfully executed."""


class V2KeysUpdateKeyResponseBody(BaseModel):
    meta: Meta
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""

    data: EmptyResponse
    r"""Empty response object by design. A successful response indicates this operation was successfully executed."""
