"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v2identitieslistidentitiesresponsebody import (
    V2IdentitiesListIdentitiesResponseBody,
    V2IdentitiesListIdentitiesResponseBodyTypedDict,
)
from typing import Callable, Optional
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class IdentitiesListIdentitiesResponseTypedDict(TypedDict):
    result: V2IdentitiesListIdentitiesResponseBodyTypedDict


class IdentitiesListIdentitiesResponse(BaseModel):
    next: Callable[[], Optional[IdentitiesListIdentitiesResponse]]

    result: V2IdentitiesListIdentitiesResponseBody
