"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from typing_extensions import Annotated, TypedDict
from unkey.py.types import BaseModel


class V2ApisGetAPIRequestBodyTypedDict(TypedDict):
    api_id: str
    r"""Specifies which API to retrieve by its unique identifier.
    Must be a valid API ID that begins with 'api_' and exists within your workspace.

    """


class V2ApisGetAPIRequestBody(BaseModel):
    api_id: Annotated[str, pydantic.Field(alias="apiId")]
    r"""Specifies which API to retrieve by its unique identifier.
    Must be a valid API ID that begins with 'api_' and exists within your workspace.

    """
