"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .role import Role, RoleTypedDict
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2PermissionsGetRoleResponseDataTypedDict(TypedDict):
    r"""Complete role details including assigned permissions."""

    role: RoleTypedDict


class V2PermissionsGetRoleResponseData(BaseModel):
    r"""Complete role details including assigned permissions."""

    role: Role
