"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from typing_extensions import Annotated, TypedDict
from unkey.py.types import BaseModel


class V2PermissionsCreatePermissionResponseDataTypedDict(TypedDict):
    permission_id: str
    r"""The unique identifier assigned to the newly created permission.
    Use this ID to reference the permission in role assignments, key operations, and other API calls.
    Always begins with 'perm_' followed by a unique alphanumeric sequence.
    Store this ID if you need to manage or reference this permission in future operations.

    """


class V2PermissionsCreatePermissionResponseData(BaseModel):
    permission_id: Annotated[str, pydantic.Field(alias="permissionId")]
    r"""The unique identifier assigned to the newly created permission.
    Use this ID to reference the permission in role assignments, key operations, and other API calls.
    Always begins with 'perm_' followed by a unique alphanumeric sequence.
    Store this ID if you need to manage or reference this permission in future operations.

    """
