"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2ApisCreateAPIRequestBodyTypedDict(TypedDict):
    name: str
    r"""Unique identifier for this API namespace within your workspace.
    Use descriptive names like 'payment-service-prod' or 'user-api-dev' to clearly identify purpose and environment.

    """


class V2ApisCreateAPIRequestBody(BaseModel):
    name: str
    r"""Unique identifier for this API namespace within your workspace.
    Use descriptive names like 'payment-service-prod' or 'user-api-dev' to clearly identify purpose and environment.

    """
