"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from typing_extensions import Annotated, TypedDict
from unkey.py.types import BaseModel


class V2IdentitiesCreateIdentityResponseDataTypedDict(TypedDict):
    identity_id: str
    r"""The unique identifier of the created identity."""


class V2IdentitiesCreateIdentityResponseData(BaseModel):
    identity_id: Annotated[str, pydantic.Field(alias="identityId")]
    r"""The unique identifier of the created identity."""
