"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .keycreditsdata import KeyCreditsData, KeyCreditsDataTypedDict
from .meta import Meta, MetaTypedDict
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2KeysUpdateCreditsResponseBodyTypedDict(TypedDict):
    meta: MetaTypedDict
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""
    data: KeyCreditsDataTypedDict
    r"""Credit configuration and remaining balance for this key."""


class V2KeysUpdateCreditsResponseBody(BaseModel):
    meta: Meta
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""

    data: KeyCreditsData
    r"""Credit configuration and remaining balance for this key."""
