"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from typing_extensions import Annotated, TypedDict
from unkey.py.types import BaseModel


class V2PermissionsCreateRoleResponseDataTypedDict(TypedDict):
    role_id: str
    r"""The unique identifier assigned to the newly created role.
    Use this ID to reference the role in permission assignments, key operations, and role management calls.
    Always begins with 'role_' followed by a unique alphanumeric sequence.
    Store this ID if you need to manage, modify, or assign this role in future operations.

    """


class V2PermissionsCreateRoleResponseData(BaseModel):
    role_id: Annotated[str, pydantic.Field(alias="roleId")]
    r"""The unique identifier assigned to the newly created role.
    Use this ID to reference the role in permission assignments, key operations, and role management calls.
    Always begins with 'role_' followed by a unique alphanumeric sequence.
    Store this ID if you need to manage, modify, or assign this role in future operations.

    """
