"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2KeysWhoamiRequestBodyTypedDict(TypedDict):
    key: str
    r"""The complete API key string provided by you, including any prefix.
    Never log, cache, or store API keys in your system as they provide full access to user resources.
    Include the full key exactly as provided - even minor modifications will cause a not found error.

    """


class V2KeysWhoamiRequestBody(BaseModel):
    key: str
    r"""The complete API key string provided by you, including any prefix.
    Never log, cache, or store API keys in your system as they provide full access to user resources.
    Include the full key exactly as provided - even minor modifications will cause a not found error.

    """
