"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2PermissionsGetPermissionRequestBodyTypedDict(TypedDict):
    permission: str
    r"""The unique identifier of the permission to retrieve. Must be a valid permission ID that begins with 'perm_' and exists within your workspace.

    """


class V2PermissionsGetPermissionRequestBody(BaseModel):
    permission: str
    r"""The unique identifier of the permission to retrieve. Must be a valid permission ID that begins with 'perm_' and exists within your workspace.

    """
