"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .meta import Meta, MetaTypedDict
from .pagination import Pagination, PaginationTypedDict
from .ratelimitoverride import RatelimitOverride, RatelimitOverrideTypedDict
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict
from unkey.py.types import BaseModel


class V2RatelimitListOverridesResponseBodyTypedDict(TypedDict):
    meta: MetaTypedDict
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""
    data: List[RatelimitOverrideTypedDict]
    pagination: NotRequired[PaginationTypedDict]
    r"""Pagination metadata for list endpoints. Provides information necessary to traverse through large result sets efficiently using cursor-based pagination."""


class V2RatelimitListOverridesResponseBody(BaseModel):
    meta: Meta
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""

    data: List[RatelimitOverride]

    pagination: Optional[Pagination] = None
    r"""Pagination metadata for list endpoints. Provides information necessary to traverse through large result sets efficiently using cursor-based pagination."""
