"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .meta import Meta, MetaTypedDict
from .v2keysverifykeyresponsedata import (
    V2KeysVerifyKeyResponseData,
    V2KeysVerifyKeyResponseDataTypedDict,
)
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2KeysVerifyKeyResponseBodyTypedDict(TypedDict):
    meta: MetaTypedDict
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""
    data: V2KeysVerifyKeyResponseDataTypedDict


class V2KeysVerifyKeyResponseBody(BaseModel):
    meta: Meta
    r"""Metadata object included in every API response. This provides context about the request and is essential for debugging, audit trails, and support inquiries. The `requestId` is particularly important when troubleshooting issues with the Unkey support team."""

    data: V2KeysVerifyKeyResponseData
