"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from typing_extensions import Annotated, TypedDict
from unkey.py.types import BaseModel


class V2RatelimitSetOverrideResponseDataTypedDict(TypedDict):
    override_id: str
    r"""The unique identifier for the newly created or updated rate limit override. This ID can be used to:

    - Reference this specific override in subsequent API calls
    - Delete or modify this override later
    - Track which override is being applied in rate limit responses
    - Associate override effects with specific rules in analytics

    Store this ID if you need to manage the override in the future.
    """


class V2RatelimitSetOverrideResponseData(BaseModel):
    override_id: Annotated[str, pydantic.Field(alias="overrideId")]
    r"""The unique identifier for the newly created or updated rate limit override. This ID can be used to:

    - Reference this specific override in subsequent API calls
    - Delete or modify this override later
    - Track which override is being applied in rate limit responses
    - Associate override effects with specific rules in analytics

    Store this ID if you need to manage the override in the future.
    """
