"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2PermissionsDeletePermissionRequestBodyTypedDict(TypedDict):
    permission: str
    r"""Specifies which permission to permanently delete from your workspace.

    This can be a permission ID or a permission slug.

    WARNING: Deleting a permission has immediate and irreversible consequences:
    - All API keys with this permission will lose that access immediately
    - All roles containing this permission will have it removed
    - Any verification requests checking for this permission will fail
    - This action cannot be undone

    Before deletion, ensure you:
    - Have updated any keys or roles that depend on this permission
    - Have migrated to alternative permissions if needed
    - Have notified affected users about the access changes

    """


class V2PermissionsDeletePermissionRequestBody(BaseModel):
    permission: str
    r"""Specifies which permission to permanently delete from your workspace.

    This can be a permission ID or a permission slug.

    WARNING: Deleting a permission has immediate and irreversible consequences:
    - All API keys with this permission will lose that access immediately
    - All roles containing this permission will have it removed
    - Any verification requests checking for this permission will fail
    - This action cannot be undone

    Before deletion, ensure you:
    - Have updated any keys or roles that depend on this permission
    - Have migrated to alternative permissions if needed
    - Have notified affected users about the access changes

    """
