"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing_extensions import TypedDict
from unkey.py.types import BaseModel


class V2PermissionsGetRoleRequestBodyTypedDict(TypedDict):
    role: str
    r"""Unique identifier of the role to permanently delete from your workspace.
    Must either be a valid role ID that begins with 'role_' or the given role name and exists within your workspace.

    Use this endpoint to verify role details, check its current permissions, or retrieve metadata.
    Returns complete role information including all assigned permissions for comprehensive access review.

    """


class V2PermissionsGetRoleRequestBody(BaseModel):
    role: str
    r"""Unique identifier of the role to permanently delete from your workspace.
    Must either be a valid role ID that begins with 'role_' or the given role name and exists within your workspace.

    Use this endpoint to verify role details, check its current permissions, or retrieve metadata.
    Returns complete role information including all assigned permissions for comprehensive access review.

    """
