"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from typing_extensions import Annotated, TypedDict
from unkey.py.types import BaseModel


class V2ApisDeleteAPIRequestBodyTypedDict(TypedDict):
    api_id: str
    r"""Specifies which API namespace to permanently delete from your workspace.
    Must be a valid API ID that begins with 'api_' and exists within your workspace.

    Before proceeding, ensure you have the correct API ID and understand that this action cannot be undone. If you need to migrate functionality, create replacement keys in a new API namespace and update client applications before deletion.

    """


class V2ApisDeleteAPIRequestBody(BaseModel):
    api_id: Annotated[str, pydantic.Field(alias="apiId")]
    r"""Specifies which API namespace to permanently delete from your workspace.
    Must be a valid API ID that begins with 'api_' and exists within your workspace.

    Before proceeding, ensure you have the correct API ID and understand that this action cannot be undone. If you need to migrate functionality, create replacement keys in a new API namespace and update client applications before deletion.

    """
